import React from 'react';
import './index.less';
export declare type CheckCardValueType = string | number | boolean;
export declare type CheckGroupValueType = CheckCardValueType[] | CheckCardValueType | undefined;
export interface CheckCardOptionType {
    /**
     * 标题展示
     *
     * @title 标题
     */
    title?: React.ReactNode;
    /**
     * 选项值
     *
     * @title 值
     */
    value: CheckCardValueType;
    /**
     * 描述展示
     *
     * @title 描述
     */
    description?: React.ReactNode;
    /**
     * 组件尺寸，支持大，中，小三种默认尺寸，用户可以自定义宽高
     *
     * @default default
     * @title 组件尺寸
     */
    size?: 'large' | 'default' | 'small';
    /**
     * 左侧头像展示，可以是一个链接也可以是是一个 ReactNode
     *
     * @title 左侧头像区域
     */
    avatar?: React.ReactNode;
    /**
     * 图片封面默认，该模式下其他展示值被忽略
     *
     * @title 图片封面
     */
    cover?: React.ReactNode;
    /**
     * 不可用
     *
     * @default false
     * @title 不可用
     */
    disabled?: boolean;
    /** Change 回调 */
    onChange?: (checked: boolean) => void;
}
export interface AbstractCheckCardGroupProps {
    /** @ignore */
    prefixCls?: string;
    /** @ignore */
    className?: string;
    /** 指定可选项 */
    options?: (CheckCardOptionType | string)[];
    /** 整组失效 */
    disabled?: boolean;
    /** @ignore */
    style?: React.CSSProperties;
    /**
     * 组件尺寸，支持大，中，小三种默认尺寸，用户可以自定义宽高
     *
     * @default default
     */
    size?: 'large' | 'default' | 'small';
    /**
     * @acceptions CheckCard
     * @ignore
     */
    children?: React.ReactNode;
}
export declare const CardLoading: React.FC<{
    prefixCls: string;
}>;
export interface CheckCardGroupProps extends AbstractCheckCardGroupProps {
    /**
     * 是否多选
     *
     * @title 是否多选
     */
    multiple?: boolean;
    /**
     * 默认选中的选项
     *
     * @title 默认选中的选项
     */
    defaultValue?: CheckGroupValueType;
    /**
     * 指定选中的选项
     *
     * @title 指定选中的选项
     */
    value?: CheckGroupValueType;
    /**
     * 当卡片组内容还在加载中时，可以用 loading 展示一个占位
     *
     * @title 加载中
     */
    loading?: boolean;
    /**
     * 是否显示边框
     *
     * @title 显示边框
     */
    bordered?: boolean;
    /** 变化时回调函数 */
    onChange?: (checkedValue: CheckGroupValueType) => void;
}
export interface CheckCardGroupState {
    value: CheckGroupValueType;
    registeredValues: CheckCardValueType[];
}
export declare type CheckCardGroupConnextType = {
    toggleOption?: (option: CheckCardOptionType) => void;
    value?: any;
    disabled?: boolean;
    size?: any;
    loading?: any;
    bordered?: any;
    multiple?: any;
    registerValue?: (value: any) => void;
    cancelValue?: (value: any) => void;
};
export declare const CheckCardGroupConnext: React.Context<CheckCardGroupConnextType | null>;
declare const CheckCardGroup: React.FC<CheckCardGroupProps>;
export default CheckCardGroup;
